# awsctx

A command line tool to change active AWS profiles and add/replace profiles.

# Installation

## Using Pip

```bash
$ pip3 install awsctx
```

## Manual 

```bash
$ git clone https://github.com/aurphillus/awsctx.git
$ cd awsctx
$ python3 setup.py install
```

# Usage

## To list Profiles
```bash
$ awsctx
```
## To switch active profile
```bash
$ awsctx profile-name
```

## To add a new profile block
```bash
$ awsctx configure
```
